cordova.define("cordova-plugin-neumob.NeumobJSInterface", function(require, exports, module) {
// Copyright 2014 Neumob
// 
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
// 
//     http://www.apache.org/licenses/LICENSE-2.0
// 
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// ======================================================================
// ============================= README =================================
// ======================================================================
//
// THIS IS FOR INTERNAL USE ONLY
//
// SetAcceleration may not have any immediate effect as CProxy will
// reuse connections (WebKit behavior) including ones that are connected
// to the NProxy. If you are looking to immediately make requests after
// calling setAcceleration and expecting those requests to be either
// accelerated or not accelerated depending on what you set, then it
// would be better to use native Android networking libraries.
//
// BUGS - iOS has functionality but isn't working. Since Android is
//        priority right now among many other bugs, there will be no
//        updates until necessary.
//
// ======================================================================
// ======================================================================
// ======================================================================

var VERSION = "v1.3.6";

var exec = require("cordova/exec");

// You can add your custom callbacks
function success () {}
function fail () {}

var	Neumob = {

    // Use initialize in order to setup the Neumob library. After successful initialization,
    // your network calls will automatically use Neumob's cloud and optimizations!
    //
    // (object) appIds - Your application identifiers. Obtain this id by registering an app at portal.neumob.com.
    //          ex. { "ios" : "iosAppID" }  
    // Available platforms: "ios"
    //
    init: function(appIDs) {
        cordova.exec(success, fail, "NeumobPlugin", "neumobInitialize", [appIDs]);
        return this;
    },
    
    // Initialize call where a callback function is run after Neumob asychronously initializes. 
    //
    // (object) appIds - Your application identifiers. Obtain this id by registering an app at portal.neumob.com.
    //          ex. { "ios" : "iosAppID" }
    // (object) config - Add your configurations in this object. If no configuration is needed, leave element empty or null.
    // Available configurations: "shouldAccelerate" - Set whether the session should be accelerated. If not set, this value
    //                                                is determined by the portal. We encourage you to leave this value as
    //                                                null or to not set it unless you are doing custom A/B testing.
    //
    // (function) callback - The callback should accept 3 parameters ex. function(authenticated, initialized, authenticated):
    //     (boolean) authenticated - Returns true if the client key is authenticated by the portal.
    //     (boolean) initialized   - Returns a boolean indicating Neumob is enabled and ready to accelerate your
    //                             - network requests. Client must be authenticated before it can be initialized.
    //     (boolean) authenticated - Returns whether Neumob is currently accelerating network requests. If Neumob
    //                             is not initialized, then accelerated will return false.
    //
    initWithCallback: function(appIDs, config, callback) {
        cordova.exec(function (result) {
            var authenticated = result["authenticated"] == 1;
            var initialized = result["initialized"] == 1;
            var accelerated = result["accelerated"] == 1;
            if (callback && typeof(callback) == "function") {
                try {
                    success();
                    callback(authenticated, initialized, accelerated);
                } catch (exception) {}
            }
        }, fail, "NeumobPlugin", "neumobInitializeForConfigAndCallback", [appIDs, config]);
        return this;
    },

    // Set acceleration for the current session. Cordova is asynchronous if you'd like to be notified of when the
    // status has been updated you'll need to provide a callback function.
    //
    // (object) shouldAccelerate - Set whether the session should be accelerated. If not set, this value
    //                             is determined by the portal. We encourage you to leave this value as
    //                             null or to not set it unless you are doing custom A/B testing.
    //
    // (function) callback - The callback should accept 1 parameter accelerated:
    //     (boolean) accelerated - Returns true if the current session is accelerated.
    //
    setAcceleration: function(shouldAccelerate, callback) {
        cordova.exec(function (result) {
            if (callback && typeof(callback) == "function") {
                try {
                    success();
                    callback(result);
                } catch (exception) {}
            }
        }, fail, "NeumobPlugin", "neumobSetAcceleration", [shouldAccelerate]);
        return this;
    },

    // Terminate the current Neumob session so that requests will no longer go through the CProxy.
    //
    terminate: function() {
        cordova.exec(success, fail, "NeumobPlugin", "neumobTerminate", []);
        return this;
    }
};

console.log("Using Neumob Plugin " + VERSION);

module.exports = Neumob;

});
